# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# Copyright (C) 2017 JOSECONSCO
# Created by JOSECONSCO


# bl_info = {"name": "Draw xray",
#            "description": "Draw xray mesh",
#            "author": "JoseConseco",
#            "version": (3, 8),
#            "blender": (3, 6, 0),
#            "location": "3D View(s) -> Top Bar -> Viewport overlays",
#            "warning": "",
#            "doc_url": "https://youtu.be/srUthznXDi4",
#            "tracker_url": "https://discord.gg/cxZDbqH",
#            "category": "3D View"
#            }
#
#
if "bpy" in locals():
    import importlib
    importlib.reload(draw_xray)
    importlib.reload(draw_brush)
    importlib.reload(utils)
    importlib.reload(preferences)
    importlib.reload(update_addon)
else:
    from . import draw_xray
    from . import draw_brush
    from . import utils
    from . import preferences
    from . import update_addon

import bpy

from . import auto_load
auto_load.init()
from . import translate



def register():
    bpy.types.Scene.xray_gizmo_show = bpy.props.BoolProperty(default = True)
    auto_load.register()
    draw_xray.registerx()
    bpy.types.Scene.xray_props = bpy.props.PointerProperty(type=draw_xray.ScnDrawXrayProps)
    bpy.types.Object.xray_props = bpy.props.PointerProperty(type=draw_xray.ObjDrawXrayProps)
    bpy.utils.register_tool(draw_brush.ToolXrayQuads, after={"builtin.smooth"}, separator=True, group=True)
    bpy.types.VIEW3D_PT_overlay.append(preferences.ShadingXrayPanel)
    bpy.app.handlers.load_pre.append(draw_brush.load_pre_xray_gizmo_fix) # only to fix crash in __del__() - when checking workspace
    bpy.app.handlers.load_post.append(draw_brush.load_post_xray_gizmo_fix) # only to fix crash in __del__() - when checking workspace

    addon_prefs = utils.get_addon_preferences()
    addon_prefs.update_text = ''
    translate.register()
def unregister():
    bpy.app.handlers.load_pre.remove(draw_brush.load_pre_xray_gizmo_fix) # only to fix crash in __del__() - when checking workspace
    bpy.app.handlers.load_post.remove(draw_brush.load_post_xray_gizmo_fix)

    bpy.types.VIEW3D_PT_overlay.remove(preferences.ShadingXrayPanel)

    bpy.utils.unregister_tool(draw_brush.ToolXrayQuads)
    draw_xray.unregisterx()

    bpy.context.scene.xray_props.enable_xray = False  #! TO hide draw xray on F8 reload - place alway after removing halders (or crash)
    del bpy.types.Scene.xray_props
    del bpy.types.Object.xray_props

    auto_load.unregister()
    del bpy.types.Scene.xray_gizmo_show
    translate.unregister()
if __name__ == "__main__":
    register()
    
