import bpy
from .utils import addon_name_lowercase

class DrawXrayPreferences(bpy.types.AddonPreferences):
    bl_idname = __package__

    update_exist: bpy.props.BoolProperty(name="Update Exist", description="There is new DrawXray update",  default=False)
    update_text: bpy.props.StringProperty(name="Update text",  default='')

    def draw(self, context):
        layout = self.layout
        # row = layout.row(align=True)
        # row.prop(self, "tabs", expand=True)

        col = layout.column()
        sub_row = col.row(align=True)
        sub_row.operator(addon_name_lowercase()+".check_for_update")
        split_lines_text = self.update_text.splitlines()
        for line in split_lines_text:
            sub_row = col.row(align=True)
            sub_row.label(text=line)
        sub_row.separator()
        sub_row = col.row(align=True)
        if self.update_exist:
            sub_row.operator(addon_name_lowercase()+".update_addon", text='Install latest version').reinstall = False
        else:
            sub_row.operator(addon_name_lowercase()+".update_addon", text='Reinstall current version').reinstall = True
        sub_row.operator(addon_name_lowercase()+".rollback_addon")


def ShadingXrayPanel(self, context):
    if context.active_object and context.active_object.type == 'MESH':
        scn_xray_props = context.scene.xray_props
        obj_xray_props = context.active_object.xray_props
        shared_xray_props = scn_xray_props if obj_xray_props.settings_mode == 'GLOBAL' else obj_xray_props

        box = self.layout.box()
        row = box.row(align=True)
        row.prop(scn_xray_props, "enable_xray", expand=True, icon='MOD_SOLIDIFY', toggle=True)
        if not scn_xray_props.enable_xray:
            return

        row = box.row(align=True)
        row.prop(obj_xray_props, "settings_mode", expand=True)

        sub_box = box.box()
        sub_box.enabled = True # False for version without snap
        row = sub_box.row(align=True)
        row.prop(shared_xray_props, "draw_overlay", icon='CHECKBOX_HLT' if shared_xray_props.draw_overlay else 'CHECKBOX_DEHLT', emboss=False)
        row.prop(shared_xray_props, "draw_modifiers", icon="MODIFIER" if shared_xray_props.draw_modifiers else 'MODIFIER_OFF', icon_only=True, emboss=False)
        row.prop(scn_xray_props, "fold_overlay", icon='TRIA_DOWN' if not scn_xray_props.fold_overlay else 'TRIA_LEFT', text='', emboss=False, toggle=True)

        #* Overlay Drawing  Settings
        if shared_xray_props.draw_overlay and not scn_xray_props.fold_overlay:
            sub_col = sub_box.column()

            row = sub_col.row(align=True)
            row.prop(scn_xray_props, "show_in_mode", expand=False)
            row = sub_col.row(align=True)
            row.prop(scn_xray_props, "drawOffset")
            row = sub_col.row(align=True)
            row.prop(scn_xray_props, "polygon_opacity")
            row.prop(scn_xray_props, "edgeOpacity")
            row = sub_col.row(align=True)
            row.label(text="Faces color")
            row.prop(scn_xray_props, "face_color", text='')
            row = sub_col.row(align=True)
            row.label(text="Highlight color")
            row.prop(scn_xray_props, "highlight_color", text='')

        # Snapping
        sub_box = box.box()
        sub_box.enabled = True # False for version without snap
        # sub_box.label(text='Only in paid version')
        row = sub_box.row(align=True)
        row.prop(shared_xray_props, "enable_snapping", icon='CHECKBOX_HLT' if shared_xray_props.enable_snapping else 'CHECKBOX_DEHLT', emboss=False)
        row.prop(scn_xray_props, "fold_snap", icon='TRIA_DOWN' if not scn_xray_props.fold_snap else 'TRIA_LEFT', text='', emboss=False, toggle=True)
        if not scn_xray_props.fold_snap:
            col = sub_box.column()
            col.active = shared_xray_props.enable_snapping
            row = col.row(align=True)
            row.prop(shared_xray_props, "snap_method", text='')
            if shared_xray_props.snap_method == 'NEAREST':
                row.prop(shared_xray_props, "affect_neighbours", text='', icon='AUTOMERGE_ON' if shared_xray_props.affect_neighbours else 'AUTOMERGE_OFF')
            # row.prop(scn_xray_props, "use_simple_snap", icon='UNLOCKED' if scn_xray_props.snap_event == 'ALL' else 'LOCKED', text='')
            row = col.row(align=True)
            row.prop(shared_xray_props, "snap_target", text='')
            if shared_xray_props.snap_target == 'OBJECT':
                row.prop_search(shared_xray_props, "snap_object", context.scene, "objects", text='')
                picker_op = row.operator("xray.object_picker", icon='EYEDROPPER', text='')
                picker_op.use_scn_prop = obj_xray_props.settings_mode == 'GLOBAL'
            elif shared_xray_props.snap_target == 'COLLECTION':
                row.prop_search(shared_xray_props, "snap_collection", bpy.data, "collections", text='')
            # row.prop(scn_xray_props, "clear_cache", icon='FILE_REFRESH', text='')
            col.prop(shared_xray_props, "snap_offset")
            row = col.row(align=True)
            row.prop(scn_xray_props, "snap_event", icon='UNLOCKED' if scn_xray_props.snap_event == 'ALL' else 'LOCKED', text='')


